Struct diem_sdk::client::Client [−][src]
pub struct Client { /* fields omitted */ }Implementations
pub async fn wait_for_signed_transaction(
&'_ self,
txn: &'_ SignedTransaction,
timeout: Option<Duration>,
delay: Option<Duration>
) -> Result<Response<TransactionView>, WaitForTransactionError>
pub async fn wait_for_transaction(
&'_ self,
address: AccountAddress,
seq: u64,
expiration_time_secs: u64,
txn_hash: HashValue,
timeout: Option<Duration>,
delay: Option<Duration>
) -> Result<Response<TransactionView>, WaitForTransactionError>
pub async fn batch(
&'_ self,
requests: Vec<MethodRequest, Global>
) -> Result<Vec<Result<Response<MethodResponse>, Error>, Global>, Error>
pub async fn request(
&'_ self,
request: MethodRequest
) -> Result<Response<MethodResponse>, Error>
pub async fn get_metadata_by_version(
&'_ self,
version: u64
) -> Result<Response<MetadataView>, Error>
pub async fn get_account(
&'_ self,
address: AccountAddress
) -> Result<Response<Option<AccountView>>, Error>
pub async fn get_account_by_version(
&'_ self,
address: AccountAddress,
version: u64
) -> Result<Response<Option<AccountView>>, Error>
pub async fn get_transactions(
&'_ self,
start_seq: u64,
limit: u64,
include_events: bool
) -> Result<Response<Vec<TransactionView, Global>>, Error>
pub async fn get_account_transaction(
&'_ self,
address: AccountAddress,
seq: u64,
include_events: bool
) -> Result<Response<Option<TransactionView>>, Error>
pub async fn get_account_transactions(
&'_ self,
address: AccountAddress,
start_seq: u64,
limit: u64,
include_events: bool
) -> Result<Response<Vec<TransactionView, Global>>, Error>
pub async fn get_events(
&'_ self,
key: EventKey,
start_seq: u64,
limit: u64
) -> Result<Response<Vec<EventView, Global>>, Error>
pub async fn get_currencies(
&'_ self
) -> Result<Response<Vec<CurrencyInfoView, Global>>, Error>
pub async fn get_state_proof(
&'_ self,
from_version: u64
) -> Result<Response<StateProofView>, Error>
pub async fn get_accumulator_consistency_proof(
&'_ self,
client_known_version: Option<u64>,
ledger_version: Option<u64>
) -> Result<Response<AccumulatorConsistencyProofView>, Error>
pub async fn get_account_state_with_proof(
&'_ self,
address: AccountAddress,
from_version: Option<u64>,
to_version: Option<u64>
) -> Result<Response<AccountStateWithProofView>, Error>
pub async fn get_transactions_with_proofs(
&'_ self,
start_version: u64,
limit: u64,
include_events: bool
) -> Result<Response<Option<TransactionsWithProofsView>>, Error>
pub async fn get_account_transactions_with_proofs(
&'_ self,
address: AccountAddress,
start_seq: u64,
limit: u64,
include_events: bool,
ledger_version: Option<u64>
) -> Result<Response<AccountTransactionsWithProofView>, Error>
pub async fn get_events_with_proofs(
&'_ self,
key: EventKey,
start_seq: u64,
limit: u64
) -> Result<Response<Vec<EventWithProofView, Global>>, Error>
pub async fn get_event_by_version_with_proof(
&'_ self,
key: EventKey,
version: Option<u64>
) -> Result<Response<EventByVersionWithProofView>, Error>
pub async fn get_deserialized_events<T>(
&'_ self,
event_key: &'_ EventKey,
start_seq: u64,
limit: u64
) -> Result<Response<Vec<Event<T>, Global>>, Error> where
T: MoveStructType + DeserializeOwned,
pub async fn get_deserialized_events<T>(
&'_ self,
event_key: &'_ EventKey,
start_seq: u64,
limit: u64
) -> Result<Response<Vec<Event<T>, Global>>, Error> where
T: MoveStructType + DeserializeOwned,
Return the events of type T that have been emitted to event_key since start_seq, with a max of limit
results
Returns an empty vector if there are no such events
The type T must match the event types associated with event_key
pub async fn get_deserialized_resource<T>(
&'_ self,
address: AccountAddress
) -> Result<Response<Option<T>>, Error> where
T: MoveResource,
pub async fn get_deserialized_resource<T>(
&'_ self,
address: AccountAddress
) -> Result<Response<Option<T>>, Error> where
T: MoveResource,
Deserialize and return the resource value of type T stored under address
Returns None if there is no such value